==> recime-bot-runtime-2017.10.21208.tgz: package/src/dialog.ts <==
import fs = require('fs');
import HandleBars = require("handlebars");
import path = require("path");

interface Context {
    uid : string
    filepath? : string,
    homedir?: string,
    title?: string,
    description?: string,
    icon?: string
}

export class Dialog {
    static html(context: Context){
        return new Promise((resolve, reject)=>{
            fs.readFile(context.filepath, 'utf-8', (err, code)=>{
                if (err){
                    return reject(err);
                }
                const packagePath = `${context.homedir}/${context.uid}/package.json`;
                
                fs.readFile(packagePath, 'utf-8', (err, body)=>{
                        const metadata = JSON.parse(body);
                        const iconPath = path.join(context.homedir, context.uid, "icon.png");
                        fs.readFile(iconPath, (err, icon)=>{
                            if (err){
                                console.error(err);
                            }
                            var template = HandleBars.compile(code);
                            context.title = metadata.name;
                            context.description = metadata.description;
                            if (icon){
                                context.icon = "data:image/jpeg;base64," + new Buffer(icon).toString("base64");
                            }
                            resolve(template(context));
                        });
                });
            });
        });
    }
}

==> recime-bot-runtime-2017.11.131109.tgz: package/src/dialog.ts <==
import fs = require('fs');
import HandleBars = require("handlebars");
import path = require("path");

import {MainModule} from "./engine/main-module";

interface Context {
    uid : string
    filepath? : string,
    homedir?: string,
    title?: string,
    description?: string,
    icon?: string
}

export class Dialog {
    static html(context: Context){
        return new Promise((resolve, reject)=>{
            fs.readFile(context.filepath, 'utf-8', (err, code)=>{
                if (err){
                    return reject(err);
                }
                const mainModule = new MainModule(context);
                const packagePath = path.join(mainModule.dir, "package.json");
                
                fs.readFile(packagePath, 'utf-8', (err, body)=>{
                        console.log(err);
                        const metadata = JSON.parse(body);
                        const iconPath = path.join(mainModule.dir, "icon.png");
                        fs.readFile(iconPath, (err, icon)=>{
                            if (err){
                                console.error(err);
                            }
                            var template = HandleBars.compile(code);
                            context.title = metadata.name;
                            context.description = metadata.description;
                            if (icon){
                                context.icon = "data:image/jpeg;base64," + new Buffer(icon).toString("base64");
                            }
                            resolve(template(context));
                        });
                });
            });
        });
    }
}
